==> jc-1.4.0.tar.gz: java/awt/GridBagLayoutInfo.h <==
// class java.awt.GridBagLayoutInfo

// class file dependencies
// @dep_class 5db28853df648842 java_awt_GridBagLayoutInfo
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_GridBagLayoutInfo_H_
#define _JC_java_awt_GridBagLayoutInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_GridBagLayoutInfo$sub_refs	_jc_java_awt_GridBagLayoutInfo$sub_refs;
typedef struct _jc_java_awt_GridBagLayoutInfo$sub_nonrefs	_jc_java_awt_GridBagLayoutInfo$sub_nonrefs;
typedef struct _jc_java_awt_GridBagLayoutInfo$refs	_jc_java_awt_GridBagLayoutInfo$refs;
typedef struct _jc_java_awt_GridBagLayoutInfo$nonrefs	_jc_java_awt_GridBagLayoutInfo$nonrefs;
typedef struct _jc_java_awt_GridBagLayoutInfo$object	_jc_java_awt_GridBagLayoutInfo$object;

typedef struct _jc_java_awt_GridBagLayoutInfo$fields_struct	_jc_java_awt_GridBagLayoutInfo$fields_struct;
typedef const struct _jc_java_awt_GridBagLayoutInfo$vmethods	_jc_java_awt_GridBagLayoutInfo$vmethods;
typedef const struct _jc_java_awt_GridBagLayoutInfo$vtable	_jc_java_awt_GridBagLayoutInfo$vtable;
typedef const struct _jc_java_awt_GridBagLayoutInfo$vtype	_jc_java_awt_GridBagLayoutInfo$vtype;

// Class fields structure
struct _jc_java_awt_GridBagLayoutInfo$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_GridBagLayoutInfo$fields_struct _jc_java_awt_GridBagLayoutInfo$class_fields;

// Constructors
extern void _jc_java_awt_GridBagLayoutInfo$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java_awt_GridBagLayoutInfo$object *, jint, jint);

// Virtual methods structure
struct _jc_java_awt_GridBagLayoutInfo$vmethods {
};

// Vtable
struct _jc_java_awt_GridBagLayoutInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_GridBagLayoutInfo$vmethods	java_awt_GridBagLayoutInfo;
};

// Vtype
struct _jc_java_awt_GridBagLayoutInfo$vtype {
	_jc_type			type;
	_jc_java_awt_GridBagLayoutInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_GridBagLayoutInfo$sub_refs {
	_jc_int_array	*colWidths;
	_jc_int_array	*rowHeights;
	_jc_double_array	*colWeights;
	_jc_double_array	*rowWeights;
};

// Reference instance fields (object)
struct _jc_java_awt_GridBagLayoutInfo$refs {
    _jc_java_awt_GridBagLayoutInfo$sub_refs	java_awt_GridBagLayoutInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_GridBagLayoutInfo$sub_nonrefs {
	jint	pos__5fx;
	jint	pos__5fy;
	jint	cols;
	jint	rows;
};

// Non-reference instance fields (object)
struct _jc_java_awt_GridBagLayoutInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_GridBagLayoutInfo$sub_nonrefs	java_awt_GridBagLayoutInfo;
};

// Object instance structure
struct _jc_java_awt_GridBagLayoutInfo$object {
	_jc_java_awt_GridBagLayoutInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_GridBagLayoutInfo$vtype	*vtype;
	_jc_java_awt_GridBagLayoutInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_GridBagLayoutInfo$vtype _jc_java_awt_GridBagLayoutInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_GridBagLayoutInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_GridBagLayoutInfo$class_object;

#endif	/* _JC_java_awt_GridBagLayoutInfo_H_ */

==> jc-1.4.6.tar.gz: java/awt/GridBagLayoutInfo.h <==
// class java.awt.GridBagLayoutInfo

// class file dependencies
// @dep_class 5db28853df648842 java_awt_GridBagLayoutInfo
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_GridBagLayoutInfo_H_
#define _JC_java_awt_GridBagLayoutInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_GridBagLayoutInfo$sub_refs	_jc_java_awt_GridBagLayoutInfo$sub_refs;
typedef struct _jc_java_awt_GridBagLayoutInfo$sub_nonrefs	_jc_java_awt_GridBagLayoutInfo$sub_nonrefs;
typedef struct _jc_java_awt_GridBagLayoutInfo$refs	_jc_java_awt_GridBagLayoutInfo$refs;
typedef struct _jc_java_awt_GridBagLayoutInfo$nonrefs	_jc_java_awt_GridBagLayoutInfo$nonrefs;
typedef struct _jc_java_awt_GridBagLayoutInfo$object	_jc_java_awt_GridBagLayoutInfo$object;

typedef struct _jc_java_awt_GridBagLayoutInfo$fields_struct	_jc_java_awt_GridBagLayoutInfo$fields_struct;
typedef const struct _jc_java_awt_GridBagLayoutInfo$vmethods	_jc_java_awt_GridBagLayoutInfo$vmethods;
typedef const struct _jc_java_awt_GridBagLayoutInfo$vtable	_jc_java_awt_GridBagLayoutInfo$vtable;
typedef const struct _jc_java_awt_GridBagLayoutInfo$vtype	_jc_java_awt_GridBagLayoutInfo$vtype;

// Class fields structure
struct _jc_java_awt_GridBagLayoutInfo$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_awt_GridBagLayoutInfo$fields_struct _jc_java_awt_GridBagLayoutInfo$class_fields;

// Constructors
extern void _jc_java_awt_GridBagLayoutInfo$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_java_awt_GridBagLayoutInfo$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_GridBagLayoutInfo$vmethods {
};

// Vtable
struct _jc_java_awt_GridBagLayoutInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_GridBagLayoutInfo$vmethods	java_awt_GridBagLayoutInfo;
};

// Vtype
struct _jc_java_awt_GridBagLayoutInfo$vtype {
	_jc_type			type;
	_jc_java_awt_GridBagLayoutInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_GridBagLayoutInfo$sub_refs {
	_jc_int_array	*colWidths;
	_jc_int_array	*rowHeights;
	_jc_double_array	*colWeights;
	_jc_double_array	*rowWeights;
};

// Reference instance fields (object)
struct _jc_java_awt_GridBagLayoutInfo$refs {
    _jc_java_awt_GridBagLayoutInfo$sub_refs	java_awt_GridBagLayoutInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_GridBagLayoutInfo$sub_nonrefs {
	jint	pos__5fx;
	jint	pos__5fy;
	jint	cols;
	jint	rows;
};

// Non-reference instance fields (object)
struct _jc_java_awt_GridBagLayoutInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_GridBagLayoutInfo$sub_nonrefs	java_awt_GridBagLayoutInfo;
};

// Object instance structure
struct _jc_java_awt_GridBagLayoutInfo$object {
	_jc_java_awt_GridBagLayoutInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_GridBagLayoutInfo$vtype	*vtype;
	_jc_java_awt_GridBagLayoutInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_GridBagLayoutInfo$vtype _jc_java_awt_GridBagLayoutInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_GridBagLayoutInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_GridBagLayoutInfo$class_object;

#endif	/* _JC_java_awt_GridBagLayoutInfo_H_ */
